# The Cyberiada State Machine Python 3 Library

The native Python 3 library for processing CyberiadaML - the version of GraphML for storing state machine graphs
used by the Cyberiada Project. 

The code is distributed under the Lesser GNU Public License (version 3), the documentation -- under
the GNU Free Documentation License (version 1.3).

## Requirements

* `poetry` (which installs latter libraries)
* `xmltodict`
* `pydantic`
* `types-xmltodict`

**Github: https://github.com/kruzhok-team/cyberiadaml-py**